import { __decorate, __metadata, __param } from 'tslib';
import { ɵɵdefineInjectable, Injectable, ElementRef, Optional, Inject, Input, Component, ViewEncapsulation, ChangeDetectionStrategy, NgModule } from '@angular/core';
import { DOCUMENT } from '@angular/common';

let FontAwesomeIconsRegistry = class FontAwesomeIconsRegistry {
    constructor() {
        this.registry = new Map();
    }
    registerIcons(icons) {
        icons.forEach((icon) => this.registry.set(icon.name, icon.data));
    }
    getIcon(iconName) {
        if (!this.registry.has(iconName)) {
            console.warn(`We could not find the dinosaur Icon with the name ${iconName}, did you add it to the Icon registry?`);
        }
        return this.registry.get(iconName);
    }
};
FontAwesomeIconsRegistry.ɵprov = ɵɵdefineInjectable({ factory: function FontAwesomeIconsRegistry_Factory() { return new FontAwesomeIconsRegistry(); }, token: FontAwesomeIconsRegistry, providedIn: "root" });
FontAwesomeIconsRegistry = __decorate([
    Injectable({
        providedIn: 'root'
    })
], FontAwesomeIconsRegistry);

let FontAwesomeIconComponent = class FontAwesomeIconComponent {
    constructor(element, iconsRegistry, document) {
        this.element = element;
        this.iconsRegistry = iconsRegistry;
        this.document = document;
    }
    set name(iconName) {
        if (this.svgIcon) {
            this.element.nativeElement.removeChild(this.svgIcon);
        }
        const svgData = this.iconsRegistry.getIcon(iconName);
        if (svgData) {
            this.svgIcon = this.svgElementFromString(svgData);
            this.element.nativeElement.appendChild(this.svgIcon);
        }
    }
    svgElementFromString(svgContent) {
        const div = this.document.createElement('DIV');
        if (div instanceof HTMLElement) {
            div.innerHTML = svgContent;
            return div.querySelector('svg') || this.document.createElementNS('http://www.w3.org/2000/svg', 'path');
        }
    }
};
FontAwesomeIconComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: FontAwesomeIconsRegistry },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [DOCUMENT,] }] }
];
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], FontAwesomeIconComponent.prototype, "name", null);
FontAwesomeIconComponent = __decorate([
    Component({
        selector: 'font-awesome-icon',
        template: `<ng-content></ng-content>`,
        encapsulation: ViewEncapsulation.None,
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __param(2, Optional()), __param(2, Inject(DOCUMENT)),
    __metadata("design:paramtypes", [ElementRef,
        FontAwesomeIconsRegistry, Object])
], FontAwesomeIconComponent);

var FontAwesomeIconsModule_1;
let FontAwesomeIconsModule = FontAwesomeIconsModule_1 = class FontAwesomeIconsModule {
    static forRoot() {
        return {
            ngModule: FontAwesomeIconsModule_1,
            providers: [
                FontAwesomeIconsRegistry,
            ],
        };
    }
};
FontAwesomeIconsModule = FontAwesomeIconsModule_1 = __decorate([
    NgModule({
        declarations: [FontAwesomeIconComponent],
        imports: [],
        exports: [FontAwesomeIconComponent]
    })
], FontAwesomeIconsModule);

/*
 * Public API Surface of the icons lib
 */

/**
 * Generated bundle index. Do not edit.
 */

export { FontAwesomeIconComponent, FontAwesomeIconsModule, FontAwesomeIconsRegistry };
//# sourceMappingURL=triangular-font-awesome-icons.js.map
